import wnsdk from '@tjmt/wnsdk'
import {Toast} from 'vant'
import moment from 'moment/moment'
import Vue from 'vue'

/**
 * 获取手机系统
 * @returns {string}
 * 安卓: 'android'     IOS: 'ios'
 */
export function getSystem() {
  const u = navigator.userAgent,
    isAndroid = u.indexOf('Android') > -1 || u.indexOf('Adr') > -1, // android终端
    isiOS = /iphone/gi.test(navigator.userAgent) // ios终端
  if (isAndroid) {
    return 'android'
  }
  if (isiOS) {
    return 'ios'
  }
}

/**
 * mt 提供的发送消息的方法
 * 目前使用： close（关闭当前webview）
 * @param name(String) 发送的消息String
 */
export function sendInfoToJava(name) {
  if (name === 'close') {
    localStorage.removeItem('task_accessToken')
    localStorage.removeItem('task_refreshToken')
  }
  wnsdk.page.close({
    success(result) {
      // 逻辑处理...
      localStorage.removeItem('task_accessToken')
      localStorage.removeItem('task_refreshToken')
    },
    error(error) {
      // 失败处理...
      console.log(error)
    }
  })
}
/* export function sendInfoToJava(name) {
  var u = navigator.userAgent, app = navigator.appVersion,
    isAndroid = u.indexOf('Android') > -1 || u.indexOf('Linux') > -1 // 如果输出结果是true就判定是android终端或者uc浏览器
  // var isIOS = !!u.match(/\(i[^;]+;( U;)? CPU.+Mac OS X/); //根据输出结果true或者false来判断ios终端
  const isIOS = /iphone/gi.test(navigator.userAgent) // ios终端
  //! !双叹号一般用来将后面的表达式转换为布尔型的数据（boolean）
  try{
    if (isAndroid) {
      window.WebView.showInfoFromJs(name)
    }
    if (isIOS) {
      window.webkit.messageHandlers.sendInfoToJava.postMessage(name)
    }
  }catch (e) {
    console.log(e)
    alert(e)
  }
  if (name === 'close') {
    localStorage.removeItem('task_accessToken')
    localStorage.removeItem('task_refreshToken')
  }
} */
// /**
//  * 关闭从原生APP进入后的进度条
//  */
// export function closeLoading() {
//   Toast('123')
//   wnsdk
//     .ui
//     .closeLoadingBar()
// }

/**
 * 关闭从原生APP进入后的进度条
 */
export function closeLoading() {
  const sys = getSystem(),
    obj = {
      status: 0
    }
  if (sys === 'android') {
    window.WebView.loading(JSON.stringify(obj))
  }
  if (sys === 'ios') {
    window.webkit.messageHandlers.loading.postMessage(obj)
  }
  // wnsdk
  //   .ui
  //   .closeLoadingBar()
}

/**
 * 转发
 */
export function transmit(data) {
  const type = data.thingDO.type == 1 ? '日程' : '会议'
  wnsdk
    .im
    .appLinkTransmit({
      title: `${data.createPerson.name}发起的${type}`,
      url: window.location.href,
      type: '4',
      style: '1',
      owner: '',
      time: `主题:${data.thingDO.sub}\n时间：${moment(data.thingDO.startTime).format('LLLL')} ～ ${moment(data.thingDO.endTime).format('LLLL')}`,
      logo: 'http://127.0.0.1:8001/img/%E6%B7%BB%E5%8A%A0%E6%97%A5%E7%A8%8B@3x.e5cfb2ef.png',
      success: function(result) {
      },
      error: function(error) {
      }
    })
}

/**
 * 架构选人
 */
export function choosePerson(selected = [], editSelect = []) {
  console.log(selected)
  console.log(editSelect)
  return new Promise((resolve, reject) => {
    wnsdk
      .util
      .chooseAddressBook({
        // id: Vue.ls.get('corpId'),
        id: '6',
        type: 2,
        editSelect: editSelect,
        selected: selected,
        success: (result) => {
          const data = JSON.parse(result.data)
          data.forEach(item => {
            item.id = item.corpUserId
          })
          // Toast({
          //   duration: 7000,
          //   message: JSON.stringify(result.data)
          // })
          resolve(data)
        },
        error: (error) => {
          Toast(JSON.stringify(error))
        }
      })
  })
}

/**
 * 关闭微应用
 */
export function closeMicroApp() {
  Toast('关闭微应用')
  wnsdk
    .page
    .closeMicroApp()
}

/**
 * 获取位置信息
 */
export function getLocation() {
  return new Promise((resolve, reject) => {
    wnsdk
      .device
      .location({
        success: (result) => {
          // Toast(JSON.stringify(result))
          resolve(result)
        },
        error: (error) => {
        }
      })
  })
}

/**
 * 预览
 */
export function preView(type, url, name) {
  wnsdk
    .media
    .multimediaPreview({
      type,
      url,
      name
    })
}
